@@ -6,6 +6,7 @@ use warnings;
 # use Data::Dumper;
 use Text::Amuse::Document;
 use Text::Amuse::Output;
+use Text::Amuse::Beamer;
 
 =head1 NAME
 
@@ -13,11 +14,11 @@ Text::Amuse - Perl module to generate HTML and LaTeX documents from Emacs Muse m
 
 =head1 VERSION
 
-Version 0.33
+Version 0.40
 
 =cut
 
-our $VERSION = '0.33';
+our $VERSION = '0.40';
 
 
 =head1 SYNOPSIS
@@ -211,6 +212,19 @@ sub as_latex {
     return join("", @{ $self->{_latex_output_strings} });
 }
 
+=head3 as_beamer
+
+Output the document as LaTeX, but wrap each section which doesn't
+contain a comment C<; noslide> inside a frame.
+
+=cut
+
+sub as_beamer {
+    my $self = shift;
+    my $latex = $self->_latex_obj->process;
+    return Text::Amuse::Beamer->new(latex => $latex)->process;
+}
+
 =head3 wants_toc
 
 Return true if a toc is needed because we found some headings inside.
